#[repr(C)]pub struct AttestationReport {
pub body: Body,
pub sig: Signature,
}Expand description
This structure contains both the report body and its cryptographic signature.
Fields
body: BodyThe main content of the attestation report
sig: SignatureECDSA signature verifying the report authenticity
Implementations
Sourceimpl AttestationReport
impl AttestationReport
Sourcepub fn print_report(&self)
pub fn print_report(&self)
Prints both the body and signature fields of the attestation report