#[repr(C)]pub struct Body {
pub version: u32,
pub chip_id: [u8; 16],
pub user_data: [u8; 64],
pub measure: [u8; 32],
pub reserved: [u8; 128],
pub sig_usage: u32,
pub sig_algo: u32,
}Expand description
A structure representing the body of an attestation report.
This is marked with repr(C) for C compatibility and can be serialized/deserialized.
Fields
version: u32Version number of the attestation report format
chip_id: [u8; 16]Unique identifier of the hardware chip (16 bytes)
user_data: [u8; 64]User data value (64 bytes)
measure: [u8; 32]Measurement data (32 bytes)
reserved: [u8; 128]Reserved data (128 bytes)
sig_usage: u32Indicates the purpose/usage of the signature
sig_algo: u32Algorithm used for generating the signature
Implementations
Sourceimpl Body
impl Body
Sourcepub fn print_fields(&self)
pub fn print_fields(&self)
Prints each field of the Body struct in human-readable format