MkfdIoctlSecurityAttestationArgs

Struct MkfdIoctlSecurityAttestationArgs 

#[repr(C)]
pub struct MkfdIoctlSecurityAttestationArgs { pub dcu_id: u32, pub cmd_id: u32, pub version: u32, pub request_data: *mut c_void, pub request_size: u64, pub response_data: *mut c_void, pub response_size: u64, pub fw_err: u64, }
IOCTL arguments structure for security attestation requests Note: Maintains #[repr(C)] for compatibility with kernel interface

Fields

dcu_id: u32

DCU identifier for target device

cmd_id: u32

For compatibility

version: u32

Message version number(default 1)

request_data: *mut c_void

Request structure address

request_size: u64

Request structure size

response_data: *mut c_void

Response structure address

response_size: u64

Response structure size

fw_err: u64

Firmware error address

Implementations

Source

impl MkfdIoctlSecurityAttestationArgs

pub fn new() -> Self

Creates a new instance with default values Note: Buffers are initialized as null pointers

pub fn set_attestation_args( &mut self, dcu_id: u32, userdata: [u8; 64], ) -> Result<()>

Configures attestation arguments with DCU ID and nonce

Safety

Contains unsafe operations for memory allocation and pointer manipulation

Arguments
  • dcu_id - Target DCU device identifier
  • userdata - 64-byte cryptographic nonce for attestation
pub unsafe fn free_buffers(&mut self)

Releases allocated memory buffers

Safety

Must only be called when buffers are no longer needed Calling with dangling pointers is undefined behavior

pub fn extract_report(&mut self) -> Result<Option<AttestationReport>, Error>

Extracts attestation report from response buffer

Returns:

  • Some(AttestationReport) if valid report exists
  • None if response buffer contains no valid report