Module guest

Module guest 

Re-exports

pub use rtmr::*;

Modules

rtmr

Structs

AttestationReportV1
The response from the PSP containing the generated attestation report.
AttestationReportV2
The response from the PSP containing the generated extended attestation report.
AttestationReportWrapper
Wrapper struct for both legacy attestation report and extended attestation report.
CsvGuest
A handle to the CSV guest device.
GuestPolicy
The firmware associates each guest with a guest policy that the guest owner provides. The firmware restricts what actions the hypervisor can take on the guest according to the guest policy. The policy also indicates the minimum firmware version to for the guest.
GuestReportRequest
The structure used for making guest report request to the PSP as a guest owner. This struct is defined in the Linux kernel: drivers/virt/coco/csv-guest/csv-guest.h
GuestRtmrRequest
The structure used for making guest rtmr request to the PSP as a guest owner. This struct is defined in the Linux kernel: drivers/virt/coco/csv-guest/csv-guest.h
ReportReq
Data provieded by the guest owner for requesting an attestation report from the HYGON Secure Processor.
ReportReqExt
Data provieded by the guest owner for requesting an extended attestation report from the HYGON Secure Processor.
TeeInfoSigner
TeeInfoV1
Data provieded by the guest owner for requesting an attestation report from the HYGON Secure Processor.
TeeInfoV2
Data provieded by the guest owner for requesting an extended attestation report from the HYGON Secure Processor.

Enums

AttestationReport
Enum Containing the different versions of the Attestation Report
CsvGuestIoctl
TeeInfo
Enum Containing the different versions of the Tee Info struct

Constants

ATTESTATION_EXT_MAGIC
CSV_GET_REPORT
Attestation report ioctl interface
CSV_RTMR_REQ
Rtmr operations ioctl interface