pub enum AttestationReport {
V1(AttestationReportV1),
V2(AttestationReportV2),
}Expand description
Enum Containing the different versions of the Attestation Report
Since the release of the firmware API version 1.4, the attestation report support extended format. In order to keep backwards compatibility, use enum V1(AttestationReportV1) to handling legacy attestation report.
The V2(AttestationReportV2) is referred to as extended attestation report.
Variants
V1(AttestationReportV1)
Version 1 of the Attestation Report returned by the firmware
V2(AttestationReportV2)
Version 2 of the Attestation Report returned by the firmware
Implementations