TeeInfo

Enum TeeInfo 

pub enum TeeInfo<'a> {
    V1(&'a TeeInfoV1),
    V2(&'a TeeInfoV2),
}
Enum Containing the different versions of the Tee Info struct

Since the release of the firmware API version 1.4, the tee info of the attestation report support extended format. In order to keep backwards compatibility, use enum V1(TeeInfoV1) to handling legacy tee info of the attestation report.

The V2(TeeInfoV2) is tee info struct for extended attestation report.

Variants



V1(&'a TeeInfoV1)

Version 1 of Tee info



V2(&'a TeeInfoV2)

Version 2 of Tee info

Implementations

Source

impl TeeInfo<'_>

pub fn raw(&self, data: &[u8]) -> Vec<u8>

Restore raw field from the Tee info

pub fn user_pubkey_digest(&self) -> Vec<u8>

Get user_pubkey_digest field

pub fn vm_id(&self) -> Vec<u8>

Get vm_id field

pub fn vm_version(&self) -> Vec<u8>

Get vm_version field

pub fn report_data(&self) -> Vec<u8>

Get report_data field

pub fn mnonce(&self) -> Vec<u8>

Get mnonce field

pub fn measure(&self) -> Vec<u8>

Get measure field

pub fn policy(&self) -> GuestPolicy

Get policy field

pub fn sig_usage(&self) -> u32

Get sig_usage field

pub fn sig_algo(&self) -> u32

Get sig_algo field

pub fn anonce(&self) -> u32

Get anonce field

pub fn build(&self) -> u32

Get build field

pub fn rtmr_version(&self) -> u16

Get rtmr_version field

pub fn rtmr0(&self) -> &[u8]

Get rtmr0 field

pub fn rtmr1(&self) -> &[u8]

Get rtmr1 field

pub fn rtmr2(&self) -> &[u8]

Get rtmr2 field

pub fn rtmr3(&self) -> &[u8]

Get rtmr3 field

pub fn rtmr4(&self) -> &[u8]

Get rtmr4 field