GuestPolicy

Struct GuestPolicy 

#[repr(C)]
pub struct GuestPolicy(pub u32);
The firmware associates each guest with a guest policy that the guest owner provides. The firmware restricts what actions the hypervisor can take on the guest according to the guest policy. The policy also indicates the minimum firmware version to for the guest.

The guest owner provides the guest policy to the firmware during launch. The firmware then binds the policy to the guest. The policy cannot be changed throughout the lifetime of the guest. The policy is also migrated with the guest and enforced by the destination platform firmware.

| Bit(s) | Name | Description > |––––|––––––––|———————————————————————————————> | 0 | NODBG | Debugging of the guest is disallowed when set > | 1 | NOKS | Sharing keys with other guests is disallowed when set > | 2 | ES | CSV2 is required when set > | 3 | NOSEND | Sending the guest to another platform is disallowed when set > | 4 | DOMAIN | The guest must not be transmitted to another platform that is not in the domain when set. > | 5 | CSV | The guest must not be transmitted to another platform that is not CSV capable when set. > | 6 | CSV3 | The guest must not be transmitted to another platform that is not CSV3 capable when set. > | 7 | ASID_REUSE | Sharing asids with other guests owned by same user is allowed when set > | 11:8 | HSK_VERSION | The guest must not be transmitted to another platform with a lower HSK version. > | 15:12 | CEK_VERSION | The guest must not be transmitted to another platform with a lower CEK version. > | 23:16 | API_MAJOR | The guest must not be transmitted to another platform with a lower platform version. > | 31:24 | API_MINOR | The guest must not be transmitted to another platform with a lower platform version. >

Tuple Fields

0: u32

Implementations

Source

impl GuestPolicy

pub fn nodbg(&self) -> u32

pub fn noks(&self) -> u32

pub fn es(&self) -> u32

pub fn nosend(&self) -> u32

pub fn domain(&self) -> u32

pub fn csv(&self) -> u32

pub fn csv3(&self) -> u32

pub fn asid_reuse(&self) -> u32

pub fn hsk_version(&self) -> u32

pub fn cek_version(&self) -> u32

pub fn api_major(&self) -> u32

pub fn api_minor(&self) -> u32

Source

impl GuestPolicy

pub fn xor(&self, anonce: &u32) -> Self