pub struct GuestReportRequest<'a> {
pub addr: u64,
pub len: u32,
/* private fields */
}Expand description
The structure used for making guest report request to the PSP as a guest owner. This struct is defined in the Linux kernel: drivers/virt/coco/csv-guest/csv-guest.h
Fields
addr: u64Address of the data buffer with user REPORT_DATA included, and CSV_REPORT output from PSP to be saved.
len: u32The page aligned length of the buffer start from [req_rsp_addr]
Implementations