ReportReq

Struct ReportReq 

#[repr(C)]
pub struct ReportReq { pub data: [u8; 64], pub mnonce: [u8; 16], pub hash: [u8; 32], }
Data provieded by the guest owner for requesting an attestation report from the HYGON Secure Processor.

Fields

data: [u8; 64]

Guest-provided data to be included in the attestation report

mnonce: [u8; 16]

Guest-provided mnonce to be placed in the report to provide protection

hash: [u8; 32]

hash of [data] and [mnonce] to provide protection

Implementations

Source

impl ReportReq

pub fn new(data: Option<[u8; 64]>, mnonce: [u8; 16]) -> Result<Self, Error>