#[repr(C)]pub struct ReportReqExt {
pub data: [u8; 64],
pub mnonce: [u8; 16],
pub hash: [u8; 32],
pub magic: [u8; 16],
pub flags: u32,
}Expand description
Data provieded by the guest owner for requesting an extended attestation report from the HYGON Secure Processor.
Fields
data: [u8; 64]Guest-provided data to be included in the attestation report
mnonce: [u8; 16]Guest-provided mnonce to be placed in the report to provide protection
hash: [u8; 32]hash of [data] and [mnonce] to provide protection
magic: [u8; 16]magic string to indicate extension aware request
flags: u32flags to indicate how to extend the attestation report
Implementations