#[repr(C)]pub struct TeeInfoV1 {
pub user_pubkey_digest: [u8; 32],
pub vm_id: [u8; 16],
pub vm_version: [u8; 16],
pub report_data: [u8; 64],
pub mnonce: [u8; 16],
pub measure: [u8; 32],
pub policy: GuestPolicy,
pub sig_usage: u32,
pub sig_algo: u32,
pub anonce: u32,
pub sig: Signature,
}Expand description
Data provieded by the guest owner for requesting an attestation report from the HYGON Secure Processor.
Fields
user_pubkey_digest: [u8; 32]Pubkey digest of the session used to secure communication between user/hypervisor and PSP.
vm_id: [u8; 16]The identifier of the VM custommized by the guest owner.
vm_version: [u8; 16]The version info of the VM customized by the guest owner.
report_data: [u8; 64]The challenge data for the attestation.
mnonce: [u8; 16]The random nonce generated by user to protect struct TeeInfoSigner.
measure: [u8; 32]The launch digest of the VM.
policy: GuestPolicyThe running policy of the VM.
sig_usage: u32The usage of the signature.
sig_algo: u32The algorithm of the signature.
anonce: u32The random nonce generated by firmware to tweak the attestation report.
sig: SignatureThe signature for the fields: user_pubkey_digest, vm_id, vm_version, report_data, mnonce, measure, policy,