pub struct AttestationReport {
pub mnonce: [u8; 16],
pub digest: [u8; 32],
pub policy: Policy,
pub sig_usage: [u8; 4],
pub sig_algo: [u8; 4],
pub sig1: [[u8; 16]; 9],
/* private fields */
}Fields
mnonce: [u8; 16]The random nonce generated by user to protect struct TeeInfoSigner.
digest: [u8; 32]policy: PolicyThe guest policy
sig_usage: [u8; 4]The usage of the signature.
sig_algo: [u8; 4]The algorithm of the signature.
sig1: [[u8; 16]; 9]Trait Implementations
Sourceimpl Clone for AttestationReport
impl Clone for AttestationReport
Sourcefn clone(&self) -> AttestationReport
fn clone(&self) -> AttestationReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttestationReport
impl Debug for AttestationReport
Sourceimpl<'de> Deserialize<'de> for AttestationReport
impl<'de> Deserialize<'de> for AttestationReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AttestationReport
impl PartialEq for AttestationReport
Sourcefn eq(&self, other: &AttestationReport) -> bool
fn eq(&self, other: &AttestationReport) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AttestationReport
impl Serialize for AttestationReport
impl Copy for AttestationReport
impl Eq for AttestationReport
impl StructuralPartialEq for AttestationReport