Launcher

Struct Launcher 

pub struct Launcher<T, U: AsRawFd, V: AsRawFd> { /* private fields */ }
Facilitates the correct execution of the CSV launch process.

Implementations

Source

impl<T, U: AsRawFd, V: AsRawFd> Launcher<T, U, V>

pub fn as_mut_vmfd(&mut self) -> &mut U

Give access to the vm fd to create vCPUs or such.

Source

impl<U: AsRawFd, V: AsRawFd> Launcher<New, U, V>

pub fn new(kvm: U, csv: V) -> Result<Self>

Begin the CSV launch process.

pub fn new_es(kvm: U, csv: V) -> Result<Self>

Begin the CSV2 launch process.

pub fn start(self, start: Start) -> Result<Launcher<Started, U, V>>

Create an encrypted guest context.

pub fn start_raw( self, policy: &Policy, cert: &Certificate, session: &Session, ) -> Result<Launcher<Started, U, V>>

Create an encrypted guest context.

pub fn start_with_policy_only( self, policy: Policy, ) -> Result<Launcher<Started, U, V>>

Create an encrypted guest context.

Source

impl<U: AsRawFd, V: AsRawFd> Launcher<Started, U, V>

pub fn update_data(&mut self, data: &[u8]) -> Result<()>

Encrypt guest data with its VEK.

pub fn register_kvm_enc_region(&mut self, data: &[u8]) -> Result<()>

Register the encrypted memory region to a virtual machine. Corresponds to the KVM_MEMORY_ENCRYPT_REG_REGION ioctl.

pub fn update_data_without_registration(&mut self, data: &[u8]) -> Result<()>

Encrypt guest data with its VEK, while the KVM encrypted memory region is not registered.

pub fn update_vmsa(&mut self) -> Result<()>

Encrypt the VMSA on CSV2.

pub fn measure(self) -> Result<Launcher<Measured, U, V>>

Request a measurement from the CSV firmware.

Source

impl<U: AsRawFd, V: AsRawFd> Launcher<Measured, U, V>

pub fn measurement(&self) -> Measurement

Get the measurement that the CSV platform recorded.

pub fn get_attestation_report( &mut self, mnonce: [u8; 16], ) -> Result<Box<AttestationReport>>

Get the attestation report.

pub fn inject(&mut self, secret: &Secret, guest: usize) -> Result<()>

Inject a secret into the guest.

Remarks

This should only be called after a successful attestation flow.

pub fn finish(self) -> Result<Handle>

Complete the CSV launch process.