#[repr(C)]pub struct Session {
pub body: SessionBody,
pub sig: SessionSig,
}Expand description
A secure channel between the tenant and the HYGON Secure Processor.
Fields
body: SessionBodyUsed for deriving a shared secret between the tenant and the HYGON SP.
sig: SessionSigTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Session
impl<'de> Deserialize<'de> for Session
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Copy for Session
impl Eq for Session
impl StructuralPartialEq for Session