SessionBody

Struct SessionBody 

#[repr(C)]
pub struct SessionBody {
Show 13 fields pub nonce: [u8; 16], pub wrap_tk: [u8; 32], pub wrap_iv: [u8; 16], pub wrap_mac: [u8; 32], pub session_mac: [u8; 32], pub key_id: [u8; 16], pub rnd_pub_key_data: [u8; 148], pub ms_enc: [u8; 256], pub vm_digest: [u8; 32], pub pubkey_digest: [u8; 32], pub vm_id: [u8; 16], pub vm_version: [u8; 16], pub user_data: [u8; 64],
}
the SessionBody of the session

Fields

nonce: [u8; 16]

Used for deriving a shared secret between the tenant and the HYGON SP.

wrap_tk: [u8; 32]

The TEK and TIK concatenated together and wrapped by the Key Encryption Key and the Key Integrity Key. (KIK (KEK (TEK|TIK))).

wrap_iv: [u8; 16]

The initialization vector.

wrap_mac: [u8; 32]

Integrity protection for the wrapped keys (see the wrap_tk field of this struct).

session_mac: [u8; 32]

The integrity-protected CSV session data.

key_id: [u8; 16]rnd_pub_key_data: [u8; 148]

used in random public key convert from command data buffer

ms_enc: [u8; 256]

ms_enc

vm_digest: [u8; 32]

vm_digest

pubkey_digest: [u8; 32]

pubkey_digest

vm_id: [u8; 16]

vm_id

vm_version: [u8; 16]

vm_version

user_data: [u8; 64]

user_data