#[repr(u8)]pub enum State {
Uninitialized = 0,
Initialized = 1,
Working = 2,
}Expand description
The platform state.
The underlying CSV platform behaves like a state machine and can only perform certain actions while it is in certain states.
Variants
Uninitialized = 0
The platform is uninitialized.
Initialized = 1
The platform is initialized, but not currently managing any guests.
Working = 2
The platform is initialized and is overseeing execution of encrypted guests.