Status

Struct Status 

pub struct Status {
    pub build: Build,
    pub state: State,
    pub flags: PlatformStatusFlags,
    pub guests: u32,
}
Information regarding the CSV platform’s current status.

Fields

build: Build

The build number.

state: State

The platform’s current state.

flags: PlatformStatusFlags

Additional platform information is encoded into flags.

These could describe whether encrypted state functionality is enabled, or whether the platform is self-owned.

guests: u32

The number of valid guests supervised by this platform.