Verifiable

Trait Verifiable 

pub trait Verifiable {
    type Output;

    // Required method
    fn verify(self) -> Result<Self::Output>;
}
An interface for types that may containe entities such as signatures that must be verified.

Required Associated Types

type Output

An output type for successful verification.

Required Methods

fn verify(self) -> Result<Self::Output>

Self-verifies signatures.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Verifiable for (&Certificate, &AttestationReport)

Implementation of verification for a certificate and attestation report pair

Source

fn verify(self) -> Result<(), Error>

Verifies the attestation report using the provided certificate

Source

type Output = ()

Source

impl Verifiable for (&Certificate, &Certificate)

Source

impl Verifiable for (&Certificate, &Certificate)

Source

impl Verifiable for (&Certificate, &Certificate)

Source

impl Verifiable for (&Certificate, &Session)

Source

impl<'a> Verifiable for (&'a Certificate, &'a TeeInfo<'a>)

Implementors

Source

impl<'a> Verifiable for &'a csv_rs::certs::ca::Chain

Source

impl<'a> Verifiable for &'a csv_rs::certs::Chain

Source

impl<'a> Verifiable for &'a csv_rs::certs::csv::Chain