pub enum Indeterminate<T: Debug> {
Known(T),
Unknown,
}Expand description
There are a number of error conditions that can occur between this layer all the way down to the CSV platform. Most of these cases have been enumerated; however, there is a possibility that some error conditions are not encapsulated here.
Variants