Utilities for creating a secure channel and facilitating the attestation process between the tenant and the HYGON SP.
Structs
- Initialized
- Represents a brand-new secure channel with the HYGON SP.
- Measuring
- Indicates the Session is currently accepting data to include in its measurement for comparison against the HYGON SP’s measurement.
- Session
- Describes a secure channel with the HYGON SP.
- Verified
- Denotes an agreeable measurement with the HYGON SP.