Session

Struct Session 

pub struct Session<T> {
    pub tek: Key,
    pub tik: Key,
    /* private fields */
}
Describes a secure channel with the HYGON SP.

This is required for facilitating an CSV launch and attestation.

Fields

tek: Key

Transport Encryption Key.

tik: Key

Transport Integrity Key.

Implementations

Source

impl Session<Initialized>

pub fn start(&self, chain: Chain) -> Result<Start>

Produces data needed to initiate the CSV launch sequence.

pub fn start_pdh(&self, pdh: Certificate) -> Result<Start>

Like the above start function, yet takes PDH as input instead of deriving it from a certificate chain.

pub fn measure(self) -> Result<Session<Measuring>>

Transitions to a measuring state.

Any measureable data submitted to the HYGON SP should also be included in the Session to easily compare against the HYGON SP’s measurement.

pub fn verify( self, _digest: &[u8], _build: Build, msr: Measurement, ) -> Result<Session<Verified>>

Verifies the HYGON SP’s measurement.

pub unsafe fn mock_verify(self, msr: Measurement) -> Result<Session<Verified>>

Skip verifying the measurement

Safety

This method must only be used in tests or unattested workflows.

Source

impl Session<Measuring>

pub fn update_data(&mut self, data: &[u8]) -> Result<()>

Adds additional data to the digest.

Everything measured by the HYGON SP should also be measured by the Session to ensure both measurements are the same.

pub fn verify(self, build: Build, msr: Measurement) -> Result<Session<Verified>>

Verifies the session’s measurement against the HYGON SP’s measurement.

pub fn verify_with_digest( self, build: Build, msr: Measurement, digest: &[u8], ) -> Result<Session<Verified>>

Verifies the session’s measurement against the HYGON SP’s measurement using an externally generated digest.

Source

impl Session<Verified>

pub fn secret(&self, flags: HeaderFlags, data: &[u8]) -> Result<Secret>

Creates a packet for a secret to be injected into the guest.