The firmware associates each guest with a guest policy that the guest owner provides. The
firmware restricts what actions the hypervisor can take on the guest according to the guest policy.
The policy also indicates the minimum firmware version to for the guest.
The structure used for making guest report request to the PSP as a guest owner.
This struct is defined in the Linux kernel: drivers/virt/coco/csv-guest/csv-guest.h
The structure used for making guest rtmr request to the PSP as a guest owner.
This struct is defined in the Linux kernel: drivers/virt/coco/csv-guest/csv-guest.h