pub enum TeeInfo<'a> {
V1(&'a TeeInfoV1),
V2(&'a TeeInfoV2),
}Expand description
Enum Containing the different versions of the Tee Info struct
Since the release of the firmware API version 1.4, the tee info of the attestation report support extended format. In order to keep backwards compatibility, use enum V1(TeeInfoV1) to handling legacy tee info of the attestation report.
The V2(TeeInfoV2) is tee info struct for extended attestation report.
Variants
Implementations
Sourceimpl TeeInfo<'_>
impl TeeInfo<'_>
Sourcepub fn user_pubkey_digest(&self) -> Vec<u8> ⓘ
pub fn user_pubkey_digest(&self) -> Vec<u8> ⓘ
Get user_pubkey_digest field
Sourcepub fn vm_version(&self) -> Vec<u8> ⓘ
pub fn vm_version(&self) -> Vec<u8> ⓘ
Get vm_version field
Sourcepub fn report_data(&self) -> Vec<u8> ⓘ
pub fn report_data(&self) -> Vec<u8> ⓘ
Get report_data field
Sourcepub fn policy(&self) -> GuestPolicy
pub fn policy(&self) -> GuestPolicy
Get policy field
Sourcepub fn rtmr_version(&self) -> u16
pub fn rtmr_version(&self) -> u16
Get rtmr_version field