pub struct GuestRtmrRequest<'a> {
pub buf: u64,
pub len: u64,
pub subcmd_id: u16,
pub rsvd: u16,
pub fw_error_code: u32,
/* private fields */
}Expand description
The structure used for making guest rtmr request to the PSP as a guest owner. This struct is defined in the Linux kernel: drivers/virt/coco/csv-guest/csv-guest.h
Fields
buf: u64Address of the rtmr subcommand buffer. This subcommand buffers request info and saves the response data returned by the firmware.
len: u64The length of the subcommand buffer.
subcmd_id: u16The identifier of the rtmr subcommand.
rsvd: u16The reserved field, just for alignment.
fw_error_code: u32The return code that a rtmr subcommand returned by the firmware.
Implementations
Sourceimpl<'a> GuestRtmrRequest<'a>
impl<'a> GuestRtmrRequest<'a>
Sourcepub fn new(subcmd_buf: &'a [u8], subcmd_id: CsvGuestUserRtmrSubcmd) -> Self
pub fn new(subcmd_buf: &'a [u8], subcmd_id: CsvGuestUserRtmrSubcmd) -> Self
Create a new rtmr request.
Sourcepub fn get_fw_error_code(&self) -> u32
pub fn get_fw_error_code(&self) -> u32
Return fw_error_code to the caller