Modules for interfacing with CSV Firmware Rust-fridenly API wrappers to communicate the the FFI functions.
Structs
- Attestation
Report - Header
- The header for a data packet that contains secret information to be injected into the guest.
- Header
Flags - Additional descriptions of the secret header packet.
- Launcher
- Facilitates the correct execution of the CSV launch process.
- Measured
- Launcher type-state that indicates the availability of a measurement.
- Measurement
- A measurement of the CSV guest.
- New
- Launcher type-state that indicates a brand new launch.
- Policy
- Describes a policy that the HYGON Secure Processor will enforce.
- Policy
Flags - Configurable CSV Policy options.
- Secret
- A packet containing secret information to be injected into the guest.
- Session
- A secure channel between the tenant and the HYGON Secure Processor.
- Session
Body - the SessionBody of the session
- Session
Sig - Start
- Used to establish a secure session with the HYGON SP.
- Started
- Launcher type-state that indicates an in-progress launch.