Modules for interfacing with CSV Firmware Rust-fridenly API wrappers to communicate the the FFI functions.
Structs
- Command
- The Rust-flavored, FFI-friendly version of
struct sev_issue_cmdwhich is used to pass arguments to the CSV ioctl implementation. - Firmware
- GetId
- Get the CPU’s unique ID that can be used for getting a certificate for the CEK public key.
- Identifier
- The CPU-unique identifier for the platform.
- PdhCert
Export - Retrieve the PDH and the platform certificate chain.
- PdhGen
- (Re)generate the Platform Diffie-Hellman (PDH).
- PekCert
Import - Join the platform to the domain.
- PekCsr
- Request certificate signing.
- PekGen
- Generate a new Platform Endorsement Key (PEK).
- Platform
Reset - Reset the platform’s persistent state.
- Platform
Status - Query CSV platform status.
- Platform
Status Flags - The platform’s status flags.
- Status
- Information regarding the CSV platform’s current status.
Enums
- State
- The platform state.
Constants
- GET_ID
- Get the CPU’s unique ID that can be used for getting a certificate for the CEK public key.
- PDH_
CERT_ EXPORT - Retrieve the PDH and the platform certificate chain.
- PDH_GEN
- (Re)generate the Platform Diffie-Hellman (PDH).
- PEK_
CERT_ IMPORT - Join the platform to the domain.
- PEK_CSR
- Take ownership of the platform.
- PEK_GEN
- Generate a new Platform Endorsement Key (PEK).
- PLATFORM_
RESET - Resets the CSV platform’s persistent state.
- PLATFORM_
STATUS - Gathers a status report from the CSV firmware.