pub struct Command<'a, T: Id> {
pub code: u32,
pub data: u64,
pub error: u32,
/* private fields */
}Expand description
The Rust-flavored, FFI-friendly version of struct sev_issue_cmd which is
used to pass arguments to the CSV ioctl implementation.
This struct is defined in the Linux kernel: include/uapi/linux/psp-sev.h
Fields
code: u32data: u64error: u32Implementations
Sourceimpl<'a, T: Id> Command<'a, T>
impl<'a, T: Id> Command<'a, T>
Sourcepub fn from_mut(subcmd: &'a mut T) -> Self
pub fn from_mut(subcmd: &'a mut T) -> Self
Create an CSV command with the expectation that the host platform/kernel will write to
the caller’s address space either to the data held in the Command.subcmd field or some
other region specified by the Command.subcmd field.
Sourcepub fn from(subcmd: &'a T) -> Self
pub fn from(subcmd: &'a T) -> Self
Create an CSV command with the expectation that the host platform/kernel WILL NOT mutate the caller’s address space in its response. Note: this does not actually prevent the host platform/kernel from writing to the caller’s address space if it wants to. This is primarily a semantic tool for programming against the CSV ioctl API.