#[repr(C, packed(1))]pub struct PlatformStatus {
pub version: Version,
pub state: u8,
pub flags: PlatformStatusFlags,
pub build: u8,
pub guest_count: u32,
}Expand description
Query CSV platform status.
Fields
version: VersionThe firmware version (major.minor)
state: u8The Platform State.
flags: PlatformStatusFlagsRight now the only flag that is communicated in this single byte is whether the platform is self- owned or not. If the first bit is set then the platform is externally owned. If it is cleared, then the platform is self-owned. Self-owned is the default state.
build: u8The firmware build ID for this API version.
guest_count: u32The number of valid guests maintained by the CSV firmware.