Utilities for adhering to a cached CSV chain convention.
The search path for the CSV chain is:
- The path specified in the “CSV_CHAIN” environment variable (if present).
$HOME/.cache/hygon-csv/chain/var/cache/hygon-csv/chain
An entire certificate chain can be created using the hag
utility.
Functions
- env_var
- Returns the path stored in the optional
CSV_CHAINenvironment variable. - get
- Searches for and decodes an CSV certificate chain.
- home
- Returns the “user-level” search path for the CSV
certificate chain (
$HOME/.cache/hygon-csv/chain). - path
- Returns the list of search paths in the order that they will be searched for the CSV certificate chain.
- sys
- Returns the “system-level” search path for the CSV
certificate chain (
/var/cache/hygon-csv/chain).