CSV certificates interface. Everything needed for working with HYGON CSV certificate chains.
Modules
- builtin
- HYGON’s certificates. Certificate provenance: https://cert.hygon.cn/hrk The certificate is embedded here as byte slices.
- ca
- For operating on Certificate Authority chains.
- csv
- For operating on CSV certificates.
Structs
Traits
- Signer
- An interface for types that can sign another type (i.e., a certificate).
- Verifiable
- An interface for types that may containe entities such as signatures that must be verified.