pub trait Verifiable {
type Output;
// Required method
fn verify(self) -> Result<Self::Output>;
}Expand description
An interface for types that may containe entities such as signatures that must be verified.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl Verifiable for (&Certificate, &AttestationReport)
Implementation of verification for a certificate and attestation report pair
impl Verifiable for (&Certificate, &AttestationReport)
Implementation of verification for a certificate and attestation report pair