Error module.
Enums
- Error
- Error conditions returned by the CSV platform or by layers above it (i.e., the Linux kernel).
- Indeterminate
- There are a number of error conditions that can occur between this layer all the way down to the CSV platform. Most of these cases have been enumerated; however, there is a possibility that some error conditions are not encapsulated here.